@@ -32,164 +32,177 @@ def test_get_page_info():
     trade_history = d.pop('trade_history')
     related_companies = d.pop('related_companies')
     assert d == {
-        'bvol': 5479452,
+        'bvol': 9803922,
         'cisin': 'IRO1MSMI0000',
         'cs': 27,
-        'eps': 1639,
+        'eps': 1339,
         'flow': 1,
+        'flow_name': 'بازار اول (تابلوی اصلی) بورس',
         'free_float': 33,
         'group_code': 'N1',
         'isin': 'IRO1MSMI0001',
         'l18': 'فملی',
         'l30': 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c',
-        'flow_name': 'بازار اول (تابلوی اصلی) بورس',
-        'month_average_volume': 98322903,
+        'month_average_volume': 80107878,
         'sector_name': 'فلزات اساسی',
-        'sector_pe': 15.4,
-        'tmax': 21900.0,
-        'tmin': 19820.0,
-        'week_max': 22000.0,
-        'week_min': 20010.0,
+        'sector_pe': 9.05,
+        'sps': 2452.07,
+        'tmax': 12850.0,
+        'tmin': 11630.0,
+        'week_max': 12440.0,
+        'week_min': 11990.0,
         'year_max': 39810.0,
-        'year_min': 5181.0,
-        'z': 101400000000}
+        'year_min': 9400.0,
+        'z': 200000000000}
     assert related_companies == [
-            [46348559193224090, 'فولاد', 'فولاد مبارکه اصفهان']
-            , [35425587644337450, 'فملی', 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c']
-            , [9211775239375291, 'ذوب', 'سهامی ذوب آهن  اصفهان']
-            , [28864540805361867, 'فخوز', 'فولاد  خوزستان']
-            , [66701874099226162, 'فاسمین', 'کالسیمین\u200c']
-            , [60350996279289099, 'کاوه', 'فولاد کاوه جنوب کیش']
-            , [59266699437480384, 'ارفع', 'شرکت آهن و فولاد ارفع']
-            , [41302553376174581, 'فجر', 'فولاد امیرکبیرکاشان']
-            , [70498485598181604, 'هرمز', 'فولاد هرمزگان جنوب']
-            , [8977441217024425, 'فسپا', 'گروه\u200cصنعتی\u200cسپاهان\u200c']
-            , [56324206651661881, 'فنورد', 'نوردوقطعات\u200c فولادی\u200c']
-            , [68488673556087148, 'فپنتا', 'سپنتا']
-            , [24018878640527909, 'میدکو', 'هلدینگ صنایع  معدنی خاورمیانه']
-            , [43545527030854340, 'کویر', 'تولیدی فولاد سپید فراب کویر']
-            , [66772024744156373, 'فباهنر', 'مس\u200c شهیدباهنر']
-            , [47232550823972469, 'وتوکا', 'سرمایه\u200cگذاری\u200cتوکافولاد(هلدینگ']
-            , [27814844870305607, 'کیمیا', 'معدنی کیمیای زنجان گستران']
-            , [40808043719554948, 'فولاژ', 'فولاد آلیاژی ایران']
-            , [65004959184388996, 'فایرا', 'آلومینیوم\u200cایران\u200c']
-            , [14800142337291217, 'فولای', 'صنایع فولاد آلیاژی یزد']
-            , [54277068923045214, 'فسرب', 'ملی\u200c سرب\u200cوروی\u200c ایران\u200c']
-            , [48623320733330408, 'فلوله', 'لوله\u200cوماشین\u200cسازی\u200cایران\u200c']
-            , [57875847776839336, 'فنوال', 'نورد آلومینیوم\u200c']
-            , [54419429862704331, 'فروس', 'فروسیلیس\u200c ایران\u200c']
-            , [408934423224097, 'فرآور', 'فرآوری\u200cموادمعدنی\u200cایران\u200c']
-            , [4733285133017464, 'فخاس', 'فولاد خراسان']
-            , [18004480270695404, 'فمراد', 'آلومراد']
-            , [41713045190742691, 'وسدید', 'گروه \u200cصنعتی\u200cسدید']
-            , [44296315953738727, 'فاهواز', 'نورد و لوله اهواز']
-            , [29974853866926823, 'فروی', 'ذوب روی اصفهان']
-            , [19367527798307032, 'فالوم', 'آلومتک\u200c']
-            , [20966291817819448, 'فسدید', 'لوله\u200cوتجهیزات\u200c سدید - ورشکسته']
-            , [35445515321658835, 'فماک', 'ماداکتو استیل کرد']
-            , [12874072841236826, 'فسازان', 'غلتک سازان سپاهان']
-            , [66021783818850713, 'فافزا', 'فولاد افزا سپاهان']
-            , [43716452378323683, 'فزرین', 'زرین معدن آسیا']
-            , [66514709341259550, 'فوکا', 'فولاد کاویان']
-            , [67170215467608124, 'زنگان', 'صنعت روی زنگان']
-            , [59342912854668427, 'فنفت', 'صنایع تجهیزات نفت']
-            , [42171673792069321, 'زیسکو', 'فولاد زرند ایرانیان']
-            , [26881786652328215, 'زرند', 'فولاد زرند']
-            , [67535111875054076, 'پارس متال ', 'پارس متال']
-            , [357086043812735, 'فولاد تربت', 'فولاد تربت حیدریه']
-            , [41867071915439180, 'آلومینیوم جنوب', 'مجتمع آلومینیوم جنوب']
-            , [40012411719639360, 'سیسکو', 'فولاد سیرجان ایرانیان']
-            , [48175603054578540, 'اسفراین', 'مجتمع صنعتی اسفراین']
-            , [58903026391426893, 'سیرجان', 'فولاد سیرجان']
-            , [68604686987554533, 'فماکح', 'ح . ماداکتو استیل کرد']]
+        [35425587644337450, 'فملی', 'ملی\u200c صنایع\u200c مس\u200c ایران\u200c'],
+        [46348559193224090, 'فولاد', 'فولاد مبارکه اصفهان'],
+        [9211775239375291, 'ذوب', 'سهامی ذوب آهن  اصفهان'],
+        [28864540805361867, 'فخوز', 'فولاد  خوزستان'],
+        [29974853866926823, 'فروی', 'ذوب روی اصفهان'],
+        [14800142337291217, 'فولای', 'صنایع فولاد آلیاژی یزد'],
+        [66701874099226162, 'فاسمین', 'کالسیمین\u200c'],
+        [43716452378323683, 'فزرین', 'زرین معدن آسیا'],
+        [41302553376174581, 'فجر', 'فولاد امیرکبیرکاشان'],
+        [43545527030854340, 'کویر', 'تولیدی فولاد سپید فراب کویر'],
+        [60350996279289099, 'کاوه', 'فولاد کاوه جنوب کیش'],
+        [54277068923045214, 'فسرب', 'ملی\u200c سرب\u200cوروی\u200c ایران\u200c'],
+        [66772024744156373, 'فباهنر', 'مس\u200c شهیدباهنر'],
+        [408934423224097, 'فرآور', 'فرآوری\u200cموادمعدنی\u200cایران\u200c'],
+        [67170215467608124, 'زنگان', 'صنعت روی زنگان'],
+        [27814844870305607, 'کیمیا', 'معدنی کیمیای زنجان گستران'],
+        [59266699437480384, 'ارفع', 'شرکت آهن و فولاد ارفع'],
+        [18004480270695404, 'فمراد', 'آلومراد'],
+        [12874072841236826, 'فسازان', 'غلتک سازان سپاهان'],
+        [8977441217024425, 'فسپا', 'گروه\u200cصنعتی\u200cسپاهان\u200c'],
+        [24018878640527909, 'میدکو', 'هلدینگ صنایع  معدنی خاورمیانه'],
+        [48623320733330408, 'فلوله', 'لوله\u200cوماشین\u200cسازی\u200cایران\u200c'],
+        [70498485598181604, 'هرمز', 'فولاد هرمزگان جنوب'],
+        [47232550823972469, 'وتوکا', 'سرمایه\u200cگذاری\u200cتوکافولاد(هلدینگ'],
+        [40808043719554948, 'فولاژ', 'فولاد آلیاژی ایران'],
+        [54419429862704331, 'فروس', 'فروسیلیس\u200c ایران\u200c'],
+        [44296315953738727, 'فاهواز', 'نورد و لوله اهواز'],
+        [4733285133017464, 'فخاس', 'فولاد خراسان'],
+        [65004959184388996, 'فایرا', 'آلومینیوم\u200cایران\u200c'],
+        [57875847776839336, 'فنوال', 'نورد آلومینیوم\u200c'],
+        [68488673556087148, 'فپنتا', 'سپنتا'],
+        [19367527798307032, 'فالوم', 'آلومتک\u200c'],
+        [41713045190742691, 'وسدید', 'گروه \u200cصنعتی\u200cسدید'],
+        [56324206651661881, 'فنورد', 'نوردوقطعات\u200c فولادی\u200c'],
+        [20966291817819448, 'فسدید', 'لوله\u200cوتجهیزات\u200c سدید - ورشکسته'],
+        [35445515321658835, 'فماک', 'ماداکتو استیل کرد'],
+        [59342912854668427, 'فنفت', 'صنایع تجهیزات نفت'],
+        [66021783818850713, 'فافزا', 'فولاد افزا سپاهان'],
+        [66514709341259550, 'فوکا', 'فولاد کاویان'],
+        [55373808401388162, 'فتوسا', 'تولید و توسعه سرب روی ایرانیان'],
+        [8725363201030474, 'فگستر', 'گسترش صنایع روی ایرانیان'],
+        [41867071915439180, 'آلومینیوم جنوب', 'مجتمع آلومینیوم جنوب'],
+        [26881786652328215, 'زرند', 'فولاد زرند'],
+        [58903026391426893, 'سیرجان', 'فولاد سیرجان'],
+        [67535111875054076, 'پارس متال ', 'پارس متال'],
+        [42171673792069321, 'زیسکو', 'فولاد زرند ایرانیان'],
+        [40012411719639360, 'سیسکو', 'فولاد سیرجان ایرانیان'],
+        [48175603054578540, 'اسفراین', 'مجتمع صنعتی اسفراین'],
+        [357086043812735, 'فولاد تربت', 'فولاد تربت حیدریه'],
+        [68604686987554533, 'فماکح', 'ح . ماداکتو استیل کرد'],
+        [44846320603450383, 'فروسیل', 'فروسیلیسیم خمین'],
+        [37284308569715577, 'فسبزوار', 'پارس فولاد سبزوار'],
+        [45507655586782998, 'فجهان', 'مجتمع جهان فولاد سیرجان']]
     assert trade_history.to_csv(line_terminator='\n') == (
         'date,pc,py,pmin,pmax,tno,tvol,tval\n'
-        '2020-11-04,21900.0,20860.0,21510.0,21900.0,8953,80376009,1759996883990.0\n'
-        '2020-11-02,20860.0,20910.0,20010.0,21490.0,22337,51699600,1078508781780.0\n'
-        '2020-11-01,20910.0,21540.0,20480.0,22000.0,21310,81345212,1700893566630.0\n'
-        '2020-10-31,21540.0,20580.0,20650.0,21600.0,20359,78073449,1681410500120.0\n'
-        '2020-10-28,20580.0,20790.0,19760.0,21420.0,30277,100296057,2064206435550.0\n'
-        '2020-10-27,20790.0,21800.0,20710.0,22050.0,23360,136913045,2845911615950.0\n'
-        '2020-10-26,21800.0,22900.0,21760.0,22700.0,43019,246470643,5372316739110.0\n'
-        '2020-10-24,22900.0,23990.0,22800.0,23730.0,9270,30119164,689808784080.0\n'
-        '2020-10-21,23990.0,23610.0,22660.0,24790.0,45582,148496612,3561797608680.0\n')
+        '2021-06-30,12240.0,12240.0,12180.0,12370.0,11639,61924440,758028561610.0\n'
+        '2021-06-29,12240.0,12140.0,12110.0,12410.0,13153,80738158,988626346660.0\n'
+        '2021-06-28,12140.0,12220.0,11990.0,12290.0,12556,69479692,843417628060.0\n'
+        '2021-06-27,12220.0,12420.0,12040.0,12440.0,18830,93937722,1148372777010.0\n'
+        '2021-06-26,12420.0,12310.0,12120.0,12600.0,25260,155751582,1934122998780.0\n'
+        '2021-06-23,12310.0,11830.0,12020.0,12420.0,23635,204263514,2514120310650.0\n'
+        '2021-06-22,11830.0,11540.0,11530.0,12110.0,24234,170353210,2014436805300.0\n'
+        '2021-06-21,11540.0,11600.0,11290.0,11740.0,14337,71521163,825245262840.0\n'
+        '2021-06-20,11600.0,11880.0,11450.0,11960.0,14830,73966678,858202905300.0\n')
 
 
 @patch_get_content('dey.html')
 def test_get_page_info_no_free_float():
     d = Instrument(1).get_page_data()
     assert d == {
-        'bvol': 2231446,
+        'bvol': 54000000,
         'cisin': 'IRO3BDYZ0003',
         'cs': 57,
-        'eps': 4326,
+        'eps': 242,
         'flow': 2,
+        'flow_name': 'بازار دوم فرابورس',
         'free_float': None,
         'group_code': 'Z1',
         'isin': 'IRO3BDYZ0001',
         'l18': 'دی',
         'l30': 'بانک دی',
-        'flow_name': 'بازار دوم فرابورس',
-        'month_average_volume': 25836324,
+        'month_average_volume': 0,
         'sector_name': 'بانکها و موسسات اعتباری',
-        'sector_pe': 16.69,
-        'tmax': 48324.0,
-        'tmin': 43722.0,
-        'week_max': 49934.0,
-        'week_min': 43722.0,
+        'sector_pe': 21.04,
+        'sps': None,
+        'tmax': 970.0,
+        'tmin': 878.0,
+        'week_max': 0.0,
+        'week_min': 0.0,
         'year_max': 83000.0,
-        'year_min': 2674.0,
-        'z': 6400000000}
+        'year_min': 0.0,
+        'z': 135000000000}
 
 
 @patch_get_content('kala.html')
 def test_get_page_info_no_eps():
     d = Instrument(1).get_page_data()
     assert d == {
-        'bvol': 1306165,
+        'bvol': 1000000,
         'cisin': 'IRO1KALA0001',
         'cs': 67,
         'eps': None,
         'flow': 1,
+        'flow_name': 'بازار اول (تابلوی فرعی) بورس',
         'free_float': 100,
         'group_code': 'N1',
         'isin': 'IRO1KALA0001',
         'l18': 'کالا',
         'l30': 'بورس کالای ایران',
-        'flow_name': 'بازار اول (تابلوی فرعی) بورس',
-        'month_average_volume': 5720005,
+        'month_average_volume': 3575913,
         'sector_name': 'فعالیتهای کمکی به نهادهای مالی واسط',
-        'sector_pe': 26.22,
-        'tmax': 41950.0,
-        'tmin': 37970.0,
-        'week_max': 46870.0,
-        'week_min': 37970.0,
-        'year_max': 105352.0,
-        'year_min': 12376.0,
+        'sector_pe': 12.72,
+        'sps': None,
+        'tmax': 34410.0,
+        'tmin': 31150.0,
+        'week_max': 34900.0,
+        'week_min': 31150.0,
+        'year_max': 82400.0,
+        'year_min': 26430.0,
         'z': 2500000000}
 
 
 @patch_get_content('khgostar.html')
-def test_get_page_info_no_sector_pe():
+def test_get_page_info_negative_sector_pe():
     d = Instrument(1).get_page_data()
-    assert d.items() >= {
-        'tmin': 3670.0
-        , 'tmax': 4050.0
-        , 'bvol': 15842055
-        , 'eps': 450
-        , 'free_float': 52
-        , 'l30': 'گسترش\u200cسرمایه\u200cگذاری\u200cایران\u200cخودرو'
-        , 'sector_name': 'خودرو و ساخت قطعات'
-        , 'flow_name': 'بازار اول (تابلوی اصلی) بورس'
-        , 'month_average_volume': 212159873
-        , 'l18': 'خگستر'
-        , 'sector_pe': -32.11
-        , 'z': 39605137000
-        , 'week_max': 4250.0
-        , 'week_min': 3670.0
-        , 'year_max': 21750.0
-        , 'year_min': 2616.0
-    }.items()
+    assert d == {
+        'bvol': 15842055,
+        'cisin': 'IRO1GOST0003',
+        'cs': 34,
+        'eps': 396,
+        'flow': 1,
+        'flow_name': 'بازار اول (تابلوی اصلی) بورس',
+        'free_float': 53,
+        'group_code': 'N1',
+        'isin': 'IRO1GOST0001',
+        'l18': 'خگستر',
+        'l30': 'گسترش\u200cسرمایه\u200cگذاری\u200cایران\u200cخودرو',
+        'month_average_volume': 366858421,
+        'sector_name': 'خودرو و ساخت قطعات',
+        'sector_pe': -9.7,
+        'sps': None,
+        'tmax': 2623.0,
+        'tmin': 2375.0,
+        'week_max': 2623.0,
+        'week_min': 2420.0,
+        'year_max': 12930.0,
+        'year_min': 1750.0,
+        'z': 39605137000}
 
 
 @patch_get_content('dara_yekom.txt')
